@@ -1,13 +1,11 @@
 import logging
 from datetime import datetime
 from operator import attrgetter
-from rq import Queue
-from rq import get_current_job
-from dallinger import db
-from dallinger import information
-from dallinger import models
-from dallinger.config import get_config
 
+from rq import Queue, get_current_job
+
+from dallinger import db, information, models
+from dallinger.config import get_config
 
 logger = logging.getLogger(__name__)
 
@@ -259,7 +257,9 @@ class AssignmentSubmitted(WorkerEvent):
     def award_bonus(self, bonus):
         self.log("Bonus = {}: paying bonus".format(bonus))
         self.participant.recruiter.reward_bonus(
-            self.assignment_id, bonus, self.experiment.bonus_reason()
+            self.participant,
+            bonus,
+            self.experiment.bonus_reason(),
         )
 
     def fail_data_check(self):
